@@ -16,8 +16,6 @@ public: // but don't use
   const char * name;
   GlobalCacheBase * next;
   GlobalCacheBase * * prev;
-  // The global cache lock must exist while any cache instance is active
-  static Mutex global_cache_lock;
 protected:
   Cacheable * first;
   void del(Cacheable * d);
@@ -58,9 +56,9 @@ PosibErr<Data *> get_cache_data(GlobalCache<Data> * cache,
 {
   LOCK(&cache->lock);
   Data * n = cache->find(key);
-  //CERR << "Getting " << key << " for " << cache->name << "\n";
+  //CERR << "Getting " << key << "\n";
   if (n) {
-    n->refcount++;
+    n->copy();
     return n;
   }
   PosibErr<Data *> res = Data::get_new(key, config);
@@ -84,7 +82,7 @@ PosibErr<Data *> get_cache_data(GlobalCache<Data> * cache,
   Data * n = cache->find(key);
   //CERR << "Getting " << key << "\n";
   if (n) {
-    n->refcount++;
+    n->copy();
     return n;
   }
   PosibErr<Data *> res = Data::get_new(key, config, config2);
