@@ -333,7 +333,7 @@ namespace acommon {
     {
       delete conv;
       conv = 0;
-      PosibErr<Convert *> pe = new_convert_if_needed(c, from, to,norm);
+      PosibErr<Convert *> pe = new_convert_if_needed(c, from, to, norm);
       if (pe.has_err()) return pe;
       conv = pe.data;
       return no_err;
@@ -392,7 +392,15 @@ namespace acommon {
     }
   };
 
-
+  struct MBLen 
+  {
+    enum Encoding {Other, UTF8, UCS2, UCS4} encoding;
+    MBLen() : encoding(Other) {}
+    PosibErr<void> setup(const Config &, ParmString enc);
+    unsigned operator()(const char * str, const char * stop);
+    unsigned operator()(const char * str, unsigned byte_size) {
+      return operator()(str, str + byte_size);}
+  };
 
 }
 
